/*******************************************************************************
 * 
 * jKiwi -- A virtual makeover and hairstyler application
 * Copyright (c) 2007-2008 Dan Mihai Ile, Maria Joao Roque Barbado Leal
 * 
 * This file is part of jKiwi.
 * 
 * jKiwi is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * jKiwi is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *******************************************************************************/

package tabs.hair;

import blending.BlendingComposite;

/**
 * Instances of this class represent
 * a hair color read from the XML colors file
 */
public class HairColorData {

	/**
	 * The blending mode used to obtain the desired color
	 */
	private final int blendingMode;

	/**
	 * The untranslated code name of the color
	 */
	private final String name;

	/**
	 * The 0-255 INT value for the red channel
	 */
	private final int red;

	/**
	 * The 0-255 INT value for the green channel
	 */
	private final int green;

	/**
	 * The 0-255 INT value for the blue channel
	 */
	private final int blue;

	/**
	 * Creates a new instance of this class given it's hair color data
	 * @param blendingMode the blending mode that should be used with this hair color
	 * @param name the untranslated code name of this hair color
	 * @param red an 0-255 String value for the red channel
	 * @param green an 0-255 String value for the green channel
	 * @param blue an 0-255 String value for the blue channel
	 */
	public HairColorData(String blendingMode, String name, String red, String green, String blue) {
		this.blendingMode = BlendingComposite.parse(blendingMode);
		this.name = name;
		this.red = Integer.parseInt(red);
		this.green = Integer.parseInt(green);
		this.blue = Integer.parseInt(blue);
	}

	/**
	 * The blending mode that should be used with this hair color
	 * @return an INT that represents the used blending mode
	 */
	public int getBlendingMode() {
		return blendingMode;
	}

	/**
	 * The untranslated code name of this hair color
	 * @return an String containing the untranslated code name for this hair color
	 */
	public String getName() {
		return name;
	}

	/**
	 * The 0-255 INT value for the blue channel
	 * @return the channel value
	 */
	public int getBlue() {
		return blue;
	}

	/**
	 * The 0-255 INT value for the green channel
	 * @return the channel value
	 */
	public int getGreen() {
		return green;
	}

	/**
	 * The 0-255 INT value for the red channel
	 * @return the channel value
	 */
	public int getRed() {
		return red;
	}

	/**
	 * A string representation for this hair color
	 */
	public String toString() {
		return "Name: " + name + " BlendingMode: " + blendingMode + " red: " + red + " green: " + green + " blue: " + blue;  
	}
}